@@ -568,6 +568,7 @@ class Hover(CommonObject):
     "marker": (Marker, dict),
     "radius": int,
     "radiusPlus": int,
+    "color": (ColorObject, basestring, dict),
     }
 
 class States(CommonObject):
@@ -695,6 +696,14 @@ class Breaks(ArrayObject):
     "to": [int, float],
     }
 
+class DataClasses(ArrayObject):
+    ALLOWED_OPTIONS = {
+    "color": (ColorObject, basestring, dict),
+    "from": [int, float],
+    "name": basestring,
+    "to": [int, float],
+    }
+
 class Zones(ArrayObject):
     ALLOWED_OPTIONS = {
     "color": (ColorObject, basestring, dict),
