@@ -10,6 +10,7 @@ from urllib.request import urlopen
 from jinja2 import Environment, PackageLoader
 
 import json, uuid
+import re
 import datetime
 import html
 from collections import Iterable
@@ -64,7 +65,7 @@ class Highmap(object):
         
         # Set Javascript src
         self.JSsource = [
-                'https://ajax.googleapis.com/ajax/libs/jquery/1.7.2/jquery.min.js',
+                'https://ajax.googleapis.com/ajax/libs/jquery/1.9.1/jquery.min.js',
                 'https://code.highcharts.com/maps/highmaps.js',
                 'https://code.highcharts.com/highcharts.js',  
                 'https://code.highcharts.com/maps/modules/map.js',
@@ -327,6 +328,8 @@ class Highmap(object):
         elif option_type == 'colorAxis':
             self.options.update({'colorAxis': self.options.get('colorAxis', ColorAxisOptions())})
             self.options[option_type].update_dict(**option_dict)
+        elif option_type in ["global" , "lang"]:
+            self.setOptions[option_type].update_dict(**option_dict)
         else:
             self.options[option_type].update_dict(**option_dict)
 
@@ -421,18 +424,20 @@ class Highmap(object):
     @property
     def iframe(self):
         htmlsrcdoc = html.escape(self.htmlcontent)
+        htmlsrcdoc = re.sub('\\n', ' ', htmlsrcdoc)
+        htmlsrcdoc = re.sub(' +', ' ', htmlsrcdoc)
         width = int(self.options['chart'].__dict__['width']) if self.options['chart'].__dict__.get('width') else 820
         height = int(self.options['chart'].__dict__['height']) if self.options['chart'].__dict__.get('height') else 520
         
         if self.options['chart'].__dict__.get('options3d'):
             if len(htmlsrcdoc) < 99965000 :
-                return '<iframe style="border:0;outline:none;overflow:hidden" src="data:text/html,'+ htmlsrcdoc + ' "height= ' + str(height) +' \
-                        width =' + str(width) + '></iframe>'
+                return '<iframe style="border:0;outline:none;overflow:hidden" src="data:text/html,'+ htmlsrcdoc + '" height=' + str(height) + \
+                        ' width=' + str(width) + '></iframe>'
             else:
-                return '<iframe style="border:0;outline:none;overflow:hidden" srcdoc="'+ htmlsrcdoc + ' "height= '+ str(height) + ' width = ' + str(width) + '></iframe>'
+                return '<iframe style="border:0;outline:none;overflow:hidden" srcdoc="'+ htmlsrcdoc + '" height='+ str(height) + ' width=' + str(width) + '></iframe>'
         else:
-            return '<iframe style="border:0;outline:none;overflow:hidden" srcdoc="'+ htmlsrcdoc + ' "height= '+ str(height) + ' width = ' + str(width) + '></iframe>'
-
+            return '<iframe style="border:0;outline:none;overflow:hidden" srcdoc="'+ htmlsrcdoc + '" height='+ str(height) + ' width=' + str(width) + '></iframe>'
+    
     def __str__(self):
         """return htmlcontent"""
         #self.buildhtml()
